==> haskell-fsnotify-0.3.0.1-50-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-fsnotify.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: fsnotify
version: 0.3.0.1
id: fsnotify-0.3.0.1-91aCwfrCI4D2W5yRU76pMo
key: fsnotify-0.3.0.1-91aCwfrCI4D2W5yRU76pMo
license: BSD-3-Clause
maintainer: Tom McLaughlin <tom@codedown.io>
author: Mark Dittmer <mark.s.dittmer@gmail.com>, Niklas Broberg
homepage: https://github.com/haskell-fswatch/hfsnotify
synopsis: Cross platform library for file change notification.
description:
    Cross platform library for file creation, modification,
    and deletion notification. This library builds upon
    existing libraries for platform-specific Windows, Mac,
    and Linux filesystem event notification.
category: Filesystem
abi: 91e1d2666631f319ac11eace58a53790
exposed: True
exposed-modules:
    System.FSNotify System.FSNotify.Devel
hidden-modules: System.FSNotify.Listener System.FSNotify.Path
                System.FSNotify.Polling System.FSNotify.Types System.FSNotify.Linux
import-dirs: /usr/lib/ghc-8.6.5/site-local/fsnotify-0.3.0.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/fsnotify-0.3.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/fsnotify-0.3.0.1
hs-libraries: HSfsnotify-0.3.0.1-91aCwfrCI4D2W5yRU76pMo
depends:
    async-2.2.2-5KbUJa8fnnu9oaTmXcEjsG base-4.12.0.0
    bytestring-0.10.8.2 containers-0.6.0.1 directory-1.3.3.0
    filepath-1.4.2.1 hinotify-0.4-IS8I2R52hDFJ7DhwZDgY88
    shelly-1.8.1-6bmahaHuwSgFb0RVBcGNtT text-1.2.3.1 time-1.8.0.2
    unix-2.7.2.2 unix-compat-0.5.1-7L4ZE9qc5MBJa5Jne6W69O
haddock-interfaces: /usr/share/doc/haskell-fsnotify/html/fsnotify.haddock
haddock-html: /usr/share/doc/haskell-fsnotify/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-fsnotify-0.3.0.1-52-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-fsnotify.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: fsnotify
version: 0.3.0.1
id: fsnotify-0.3.0.1-3XiZ2HBibJe5xnzsOcFwt2
key: fsnotify-0.3.0.1-3XiZ2HBibJe5xnzsOcFwt2
license: BSD-3-Clause
maintainer: Tom McLaughlin <tom@codedown.io>
author: Mark Dittmer <mark.s.dittmer@gmail.com>, Niklas Broberg
homepage: https://github.com/haskell-fswatch/hfsnotify
synopsis: Cross platform library for file change notification.
description:
    Cross platform library for file creation, modification,
    and deletion notification. This library builds upon
    existing libraries for platform-specific Windows, Mac,
    and Linux filesystem event notification.
category: Filesystem
abi: 433dde9c1e1eeaa5f1b7f3684e16d510
exposed: True
exposed-modules:
    System.FSNotify System.FSNotify.Devel
hidden-modules: System.FSNotify.Listener System.FSNotify.Path
                System.FSNotify.Polling System.FSNotify.Types System.FSNotify.Linux
import-dirs: /usr/lib/ghc-8.6.5/site-local/fsnotify-0.3.0.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/fsnotify-0.3.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/fsnotify-0.3.0.1
hs-libraries: HSfsnotify-0.3.0.1-3XiZ2HBibJe5xnzsOcFwt2
depends:
    async-2.2.2-5KbUJa8fnnu9oaTmXcEjsG base-4.12.0.0
    bytestring-0.10.8.2 containers-0.6.0.1 directory-1.3.3.0
    filepath-1.4.2.1 hinotify-0.4-IS8I2R52hDFJ7DhwZDgY88
    shelly-1.8.1-2oLD9JcjVBw8FfdIxG62cz text-1.2.3.1 time-1.8.0.2
    unix-2.7.2.2 unix-compat-0.5.1-7L4ZE9qc5MBJa5Jne6W69O
haddock-interfaces: /usr/share/doc/haskell-fsnotify/html/fsnotify.haddock
haddock-html: /usr/share/doc/haskell-fsnotify/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
